//! This part of LibRapid is designed for computer science - Huffman text compression, dates and other tools related to computers and data types.
pub mod compression;
pub mod general;
pub mod dates;
pub mod rapidlogging;
pub mod unit_conversion;
pub mod colours;
pub mod stringhelpers;